@@ -12,9 +12,9 @@ from rasterio.warp import transform_geom
 
 from rio_tiler import constants
 from rio_tiler.errors import InvalidBandName
-from rio_tiler.io import BaseReader, COGReader
+from rio_tiler.io import BaseReader, COGReader, MultiBandReader
 
-from ...reader import MultiBandReader, get_object
+from ... import get_object
 from ..utils import s2_sceneid_parser
 
 default_l1c_bands = (
@@ -68,8 +68,8 @@ class S2L1CReader(MultiBandReader):
     _hostname: str = "sentinel-s2-l1c"
     _prefix: str = "tiles/{_utm}/{lat}/{sq}/{acquisitionYear}/{_month}/{_day}/{num}"
 
-    def __enter__(self):
-        """Support using with Context Managers."""
+    def __attrs_post_init__(self):
+        """Fetch productInfo and get bounds."""
         self.scene_params = s2_sceneid_parser(self.sceneid)
 
         prefix = self._prefix.format(**self.scene_params)
@@ -80,10 +80,11 @@ class S2L1CReader(MultiBandReader):
         input_crs = CRS.from_user_input(input_geom["crs"]["properties"]["name"])
         self.datageom = transform_geom(input_crs, constants.WGS84_CRS, input_geom)
         self.bounds = featureBounds(self.datageom)
-        return self
 
     def _get_band_url(self, band: str) -> str:
         """Validate band name and return band's url."""
+        band = band if len(band) == 3 else f"B0{band[-1]}"
+
         if band not in self.bands:
             raise InvalidBandName(f"{band} is not valid")
 
@@ -178,8 +179,11 @@ class S2L2AReader(S2L1CReader):
 
     def _get_band_url(self, band: str) -> str:
         """Validate band name and return band's url."""
+        band = band if len(band) == 3 else f"B0{band[-1]}"
+
         if band not in self.bands:
             raise InvalidBandName(f"{band} is not valid")
+
         prefix = self._prefix.format(**self.scene_params)
         res = self._get_resolution(band)
         return f"{self._scheme}://{self._hostname}/{prefix}/R{res}m/{band}.jp2"
@@ -216,10 +220,10 @@ class S2COGReader(MultiBandReader):
 
     _scheme: str = "s3"
     _hostname: str = "sentinel-cogs"
-    _prefix: str = "sentinel-s2-{_levelLow}-cogs/{acquisitionYear}/{scene}"
+    _prefix: str = "sentinel-s2-{_levelLow}-cogs/{_utm}/{lat}/{sq}/{acquisitionYear}/{_month}/{scene}"
 
-    def __enter__(self):
-        """Support using with Context Managers."""
+    def __attrs_post_init__(self):
+        """Fetch item.json and get bounds and bands."""
         self.scene_params = s2_sceneid_parser(self.sceneid)
 
         cog_sceneid = self.scene_params["scene"]
@@ -234,10 +238,10 @@ class S2COGReader(MultiBandReader):
         )
         self.bounds = self.stac_item["bbox"]
 
-        return self
-
     def _get_band_url(self, band: str) -> str:
         """Validate band name and return band's url."""
+        band = band if len(band) == 3 else f"B0{band[-1]}"
+
         if band not in self.bands:
             raise InvalidBandName(f"{band} is not valid")
 
